@@ -37,6 +37,7 @@
 #include <QWebFrame>
 #include <qstandardpaths.h>
 #include <qdiriterator.h>
+#include <QRegExpValidator>
 
 #include "skgmainpanel.h"
 #include "skgtraces.h"
@@ -58,6 +59,9 @@ SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(SKGDocument* iDocument)
     ui.kGetNewHotStuff->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
     ui.kDeleteTemplate->setIcon(QIcon::fromTheme("edit-delete"));
 
+    QRegExpValidator* newValidator = new QRegExpValidator(QRegExp("^[\\w\\s]+$"), this);
+    ui.kTemplate->setValidator(newValidator);
+
     connect(getDocument(), &SKGDocument::tableModified, this, &SKGMonthlyPluginWidget::dataModified, Qt::QueuedConnection);
 
     QStringList overlays;
@@ -165,7 +169,8 @@ void SKGMonthlyPluginWidget::fillTemplateList()
 void SKGMonthlyPluginWidget::onAddTemplate()
 {
     QString templat = ui.kTemplate->text().trimmed();
-    QString templatFileName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + KAboutData::applicationData().componentName() % "/html/" % templat % ".txt";
+    QString templateDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + KAboutData::applicationData().componentName();
+    QString templatFileName = templateDir % "/html/" % templat % ".txt";
     QStringList templates;
     foreach(const QString & dir, QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, KAboutData::applicationData().componentName() % "/html", QStandardPaths::LocateDirectory)) {
         QDirIterator it(dir, QStringList() << QStringLiteral("*.txt"));
@@ -179,6 +184,7 @@ void SKGMonthlyPluginWidget::onAddTemplate()
         if (!templates.contains(templatFileName)) {
             // Create the new template
             QString source = QStandardPaths::locate(QStandardPaths::GenericDataLocation, KAboutData::applicationData().componentName() % "/html/default.txt");
+            QDir(templateDir).mkpath("html");
             if (SKGServices::upload(QUrl::fromLocalFile(source), QUrl::fromLocalFile(templatFileName))) {
                 err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Impossible to copy file from '%1' to '%2'", source, templatFileName));
             } else {
