@@ -48,27 +48,27 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState();
+    virtual QString getState() Q_DECL_OVERRIDE;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState);
+    virtual void setState(const QString& iState) Q_DECL_OVERRIDE;
 
     /**
      * Get attribute name to save the default state
      * MUST BE OVERWRITTEN
      * @return attribute name to save the default state.
      */
-    virtual QString getDefaultStateAttribute();
+    virtual QString getDefaultStateAttribute() Q_DECL_OVERRIDE;
 
     /**
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget();
+    virtual QWidget* mainWidget() Q_DECL_OVERRIDE;
 
     /**
      * Get the current month
