@@ -69,6 +69,7 @@ SKGImportPluginCsv::SKGImportPluginCsv(QObject* iImporter, const QVariantList& i
     m_parameters["columns_positions"] = "";
 
     m_parameters["mode_csv_unit"] = 'N';
+    m_parameters["mode_csv_rule"] = 'N';
 
     m_parameters["date_format"] = "";
 }
@@ -200,8 +201,14 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
 
     IFOK(err) {
         // Check if mandatory attributes have been found
-        if (!m_csvMapping.contains("date") || !m_csvMapping.contains("amount")) {
-            err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns date and amount not found. Set import parameters in settings."));
+        if (m_parameters["mode_csv_rule"] == "Y") {
+            if (!m_csvMapping.contains("payee") || !m_csvMapping.contains("category")) {
+                err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns payee and category not found. Set import parameters in settings."));
+            }
+        } else {
+            if (!m_csvMapping.contains("date") || !m_csvMapping.contains("amount")) {
+                err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns date and amount not found. Set import parameters in settings."));
+            }
         }
     }
 
@@ -236,8 +243,14 @@ SKGError SKGImportPluginCsv::setCSVHeaderIndex(int iIndex)
             while (!stream.atEnd() && m_csvHeaderIndex == -1) {
                 // Read line
                 QStringList map = getCSVMappingFromLine(stream.readLine());
-                if (map.contains("date") && map.contains("amount")) {
-                    m_csvHeaderIndex = i;
+                if (m_parameters["mode_csv_rule"] == "Y") {
+                    if (map.contains("payee") && map.contains("category")) {
+                        m_csvHeaderIndex = i;
+                    }
+                } else {
+                    if (map.contains("date") && map.contains("amount")) {
+                        m_csvHeaderIndex = i;
+                    }
                 }
 
                 ++i;
@@ -271,6 +284,10 @@ QChar SKGImportPluginCsv::getCSVSeparator()
 
 SKGError SKGImportPluginCsv::importFile()
 {
+    SKGTRACE << "mode_csv_rule=" << m_parameters["mode_csv_rule"] << endl;
+    if (m_parameters["mode_csv_rule"] == "Y") {
+        return importCSVRule();
+    }
     if (m_parameters["mode_csv_unit"] == "Y") {
         return importCSVUnit();
     }
@@ -452,7 +469,9 @@ SKGError SKGImportPluginCsv::importFile()
                                     val = atts.at(c).trimmed();
                                 }
                                 if (col == "date") {
-                                    err = currentOperation.setDate(SKGServices::stringToTime(SKGServices::dateToSqlString(val, dateFormat)).date());
+                                    QDate d = SKGServices::stringToTime(SKGServices::dateToSqlString(val, dateFormat)).date();
+                                    err = currentOperation.setDate(d);
+                                    IFOKDO(err, currentSubOperation.setDate(d));
                                     if (val == "0000-00-00") {
                                         initialBalance = true;
                                     }
@@ -712,8 +731,8 @@ SKGError SKGImportPluginCsv::exportFile()
                   "SELECT v.d_date as date, v.t_ACCOUNT as account, v.i_number as number, v.t_mode as mode, "
                   "v.t_PAYEE as payee, v.t_REALCOMMENT as comment, ROUND(v.f_REALQUANTITY, u.i_nbdecimal) as quantity, "
                   "v.t_UNIT as unit, ROUND(v.f_REALCURRENTAMOUNT, u.i_nbdecimal) as amount, v.t_TYPEEXPENSE as sign, v.t_REALCATEGORY as category, v.t_status as status, "
-                  "v.t_bookmarked as bookmarked, v.i_SUBOPID id, v.id idtransaction, v.i_group_id idgroup "
-                  "FROM v_suboperation_consolidated as v, unit as u WHERE v.rc_unit_id=u.id ORDER BY v.d_date, v.id, v.i_SUBOPID", &out, SKGServices::DUMP_CSV);
+                  "v.t_bookmarked as bookmarked, v.i_SUBOPID id, v.i_OPID idtransaction, v.i_group_id idgroup "
+                  "FROM v_suboperation_consolidated as v, unit as u WHERE v.rc_unit_id=u.id ORDER BY v.d_date, v.i_OPID, v.i_SUBOPID", &out, SKGServices::DUMP_CSV);
 
         // Close file
         file.commit();
@@ -794,7 +813,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                     if (dateFormat.isEmpty()) {
                         err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
                     }
-                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().toDisplayString(), m_importer->getCodec(), dateFormat)))
+                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with codec '%2' and date format '%3'", m_importer->getFileName().toDisplayString(), m_importer->getCodec(), dateFormat)))
 
                     // Step 2 done
                     IFOKDO(err, m_importer->getDocument()->stepForward(2))
@@ -841,4 +860,103 @@ SKGError SKGImportPluginCsv::importCSVUnit()
     return err;
 }
 
+SKGError SKGImportPluginCsv::importCSVRule()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(2, err);
+
+    if (m_importer->getDocument()) {
+        // Begin transaction
+        err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import rules"), 3);
+        IFOK(err) {
+            // File name is the name of the unit
+            QFileInfo fInfo(m_importer->getFileName().path());
+            QString unitName = fInfo.baseName();
+
+            // Default mapping
+            if (getCSVMapping().count() == 0) {
+                err = setCSVMapping(NULL);
+                IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Use automatic search of the columns")))
+            }
+
+            // Step 1 done
+            IFOKDO(err, m_importer->getDocument()->stepForward(1))
+
+            // Open file
+            IFOK(err) {
+                QFile file(m_importer->getLocalFileName());
+                if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                    err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().toDisplayString()));
+                } else {
+                    QTextStream stream(&file);
+                    if (!m_importer->getCodec().isEmpty()) {
+                        stream.setCodec(m_importer->getCodec().toLatin1().constData());
+                    }
+
+                    // Ignore useless lines
+                    int headerIndex = getCSVHeaderIndex();
+                    for (int i = 1; i <= headerIndex; ++i) {
+                        stream.readLine();
+                    }
+
+                    // Get data column
+                    QStringList lines;
+                    while (!stream.atEnd()) {
+                        // Read line
+                        QString line = stream.readLine().trimmed();
+                        if (!line.isEmpty()) {
+                            lines.push_back(line);
+                        }
+                    }
+
+                    // close file
+                    file.close();
+
+                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with codec '%2'", m_importer->getFileName().toDisplayString(), m_importer->getCodec())))
+
+                    // Step 2 done
+                    IFOKDO(err, m_importer->getDocument()->stepForward(2))
+
+                    // Treat all lines
+                    IFOK(err) {
+                        int nb = lines.size();
+                        err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import rules"), nb);
+
+                        // Save last mapping used in a settings
+                        QString mappingDesc;
+                        int nbMap = m_csvMapping.count();
+                        for (int i = 0; i < nbMap; ++i) {
+                            if (i) {
+                                mappingDesc += '|';
+                            }
+                            mappingDesc += m_csvMapping.at(i);
+                        }
+                        IFOKDO(err, m_importer->getDocument()->setParameter("SKG_LAST_CSV_RULE_MAPPING_USED", mappingDesc))
+
+                        int pospayee = m_csvMapping.indexOf("payee");
+                        int poscategory = m_csvMapping.indexOf("category");
+                        if (pospayee != -1 && poscategory != -1) {
+                            for (int i = 0; !err && i < nb; ++i) {
+                                QStringList atts = SKGServices::splitCSVLine(lines.at(i), getCSVSeparator());
+
+                                SKGRuleObject oRule;
+                                err = SKGRuleObject::createPayeeCategoryRule(m_importer->getDocument(), atts.at(pospayee), atts.at(poscategory), oRule);
+
+                                IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
+                            }
+                        }
+
+                        SKGENDTRANSACTION(m_importer->getDocument(),  err);
+
+                        // Lines treated
+                        IFOKDO(err, m_importer->getDocument()->stepForward(3))
+                    }
+                }
+            }
+        }
+        SKGENDTRANSACTION(m_importer->getDocument(),  err);
+    }
+    return err;
+}
+
 #include <skgimportplugincsv.moc>
