@@ -88,6 +88,13 @@ public:
      */
     virtual SKGError importCSVUnit();
 
+    /**
+     * Import rules
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    virtual SKGError importCSVRule();
+
 private:
     Q_DISABLE_COPY(SKGImportPluginCsv)
 
