@@ -49,7 +49,7 @@ K_PLUGIN_FACTORY(SKGImportExportPluginFactory, registerPlugin<SKGImportExportPlu
 
 SKGImportExportPlugin::SKGImportExportPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
-    m_importAction(NULL), m_importBackendAction(NULL), m_importCsvUnitAction(NULL), m_exportFileAction(NULL),
+    m_importAction(NULL), m_importBackendAction(NULL), m_importCsvUnitAction(NULL), m_importCsvRuleAction(NULL), m_exportFileAction(NULL),
     m_processingFoundTransfert(NULL), m_processingBank(NULL), m_processingAnonymize(NULL), m_validateImportedOperationsAction(NULL),
     m_openNotValidatedAction(NULL), m_mergeImportedOperationAction(NULL), m_currentBankDocument(NULL),
     m_install(false)
@@ -66,6 +66,7 @@ SKGImportExportPlugin::~SKGImportExportPlugin()
     m_importAction = NULL;
     m_importBackendAction = NULL;
     m_importCsvUnitAction = NULL;
+    m_importCsvRuleAction = NULL;
     m_exportFileAction = NULL;
     m_processingFoundTransfert = NULL;
     m_processingAnonymize = NULL;
@@ -119,11 +120,19 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     overlaycsv.push_back("text-csv");
     m_importCsvUnitAction = new QAction(SKGServices::fromTheme("document-import", overlaycsv), i18nc("Verb, action to import", "Import currency values..."), this);
     connect(m_importCsvUnitAction, &QAction::triggered, [ = ]() {
-        this->import();
+        this->import(QList<QUrl>(), 2);
     });
     imports->addAction(m_importCsvUnitAction);
     registerGlobalAction("import_csv_unit", m_importCsvUnitAction);
 
+    // Import CSV Rule
+    m_importCsvRuleAction = new QAction(SKGServices::fromTheme("document-import", overlaycsv), i18nc("Verb, action to import", "Import rules..."), this);
+    connect(m_importCsvRuleAction, &QAction::triggered, [ = ]() {
+        this->import(QList<QUrl>(), 3);
+    });
+    imports->addAction(m_importCsvRuleAction);
+    registerGlobalAction("import_csv_rule", m_importCsvRuleAction);
+
     // Exports
     KActionMenu* exports = new  KActionMenu(QIcon::fromTheme("document-export"), i18nc("Verb, action to export items in another format", "Export"), this);
     registerGlobalAction("export", exports);
@@ -459,7 +468,7 @@ void SKGImportExportPlugin::import(const QString& iFile)
     import(QList<QUrl>() << QUrl::fromLocalFile(iFile));
 }
 
-void SKGImportExportPlugin::import(const QList<QUrl>& iFiles)
+void SKGImportExportPlugin::import(const QList<QUrl>& iFiles, int mode)
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
@@ -535,7 +544,8 @@ void SKGImportExportPlugin::import(const QList<QUrl>& iFiles)
 
                         parameters["automatic_search_columns"] = (skgimportexport_settings::automatic_search_columns() ? "Y" : "N");
                         parameters["columns_positions"] = skgimportexport_settings::columns_positions();
-                        parameters["mode_csv_unit"] = (sender() == m_importCsvUnitAction ? "Y" : "N");
+                        parameters["mode_csv_unit"] = (mode == 2 ? "Y" : "N");
+                        parameters["mode_csv_rule"] = (mode == 3 ? "Y" : "N");
                         parameters["date_format"] = skgimportexport_settings::csv_date_format();
                         if (!parameters["date_format"].contains("YY")) {
                             parameters["date_format"] = "";
