@@ -133,7 +133,7 @@ Q_SIGNALS:
 
 private Q_SLOTS:
     void import(const QString& iFile);
-    void import(const QList<QUrl>& iFiles = QList<QUrl>());
+    void import(const QList<QUrl>& iFiles = QList<QUrl>(), int mode = 1); // 1=operations, 2=unit, 3=rules
     SKGError importbackends();
     void exportFile();
     void findTransfers();
@@ -150,6 +150,7 @@ private:
     QAction* m_importAction;
     QAction* m_importBackendAction;
     QAction* m_importCsvUnitAction;
+    QAction* m_importCsvRuleAction;
     QAction* m_exportFileAction;
     QAction* m_processingFoundTransfert;
     QAction* m_processingBank;
