@@ -58,7 +58,7 @@ SKGOperationPlugin::SKGOperationPlugin(QWidget* iWidget, QObject* iParent, const
     SKGInterfacePlugin(iParent),
     m_duplicateAction(NULL), m_createTemplateAction(NULL), m_switchToPointedAction(NULL), m_openHighLights(NULL), m_openLastModified(NULL),
     m_openSuboperations(NULL), m_openDuplicate(NULL), m_groupOperation(NULL), m_ungroupOperation(NULL), m_mergeOperationAction(NULL),
-    m_open(NULL), m_applyTemplateAction(NULL), m_applyTemplateMenu(NULL), m_currentBankDocument(NULL)
+    m_open(NULL), m_cleanAlignDate(NULL), m_cleanAlignComment(NULL), m_cleanRemoveGroupWithOneOperation(NULL), m_applyTemplateAction(NULL), m_applyTemplateMenu(NULL), m_currentBankDocument(NULL)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -81,6 +81,9 @@ SKGOperationPlugin::~SKGOperationPlugin()
     m_open = NULL;
     m_applyTemplateAction = NULL;
     m_applyTemplateMenu = NULL;
+    m_cleanAlignDate = NULL;
+    m_cleanAlignComment = NULL;
+    m_cleanRemoveGroupWithOneOperation = NULL;
 }
 
 bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -234,14 +237,14 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     registerGlobalAction("view_open_operation_with_date_not_aligned", actTmp);
 
     // ------------
-    actTmp = new QAction(SKGServices::fromTheme("draw-freehand", overlayrun), i18nc("Verb", "Align comment of suboperations"), this);
-    connect(actTmp, &QAction::triggered, this, &SKGOperationPlugin::onAlignComment);
-    registerGlobalAction("clean_align_comment", actTmp);
+    m_cleanAlignComment = new QAction(SKGServices::fromTheme("draw-freehand", overlayrun), i18nc("Verb", "Align comment of suboperations of all operations"), this);
+    connect(m_cleanAlignComment, &QAction::triggered, this, &SKGOperationPlugin::onAlignComment);
+    registerGlobalAction("clean_align_comment", m_cleanAlignComment);
 
     // ------------
-    actTmp = new QAction(SKGServices::fromTheme("view-pim-calendar", overlayrun), i18nc("Verb", "Align date of suboperations"), this);
-    connect(actTmp, &QAction::triggered, this, &SKGOperationPlugin::onAlignDate);
-    registerGlobalAction("clean_align_date", actTmp);
+    m_cleanAlignDate = new QAction(SKGServices::fromTheme("view-pim-calendar", overlayrun), i18nc("Verb", "Align date of suboperations of all operations"), this);
+    connect(m_cleanAlignDate, &QAction::triggered, this, &SKGOperationPlugin::onAlignDate);
+    registerGlobalAction("clean_align_date", m_cleanAlignDate);
 
     // ------------
     actTmp = new QAction(SKGServices::fromTheme("view-financial-transfer", overlayopen), i18nc("Verb", "Open operations in groups with only one operation..."), this);
@@ -253,9 +256,9 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     registerGlobalAction("view_open_operation_in_group_of_one", actTmp);
 
     // ------------
-    actTmp = new QAction(SKGServices::fromTheme("view-financial-transfer", overlayrun), i18nc("Verb", "Remove groups with only one operation."), this);
-    connect(actTmp, &QAction::triggered, this, &SKGOperationPlugin::onRemoveGroupWithOneOperation);
-    registerGlobalAction("clean_remove_group_with_one_operation", actTmp);
+    m_cleanRemoveGroupWithOneOperation = new QAction(SKGServices::fromTheme("view-financial-transfer", overlayrun), i18nc("Verb", "Remove groups with only one operation of all operations"), this);
+    connect(m_cleanRemoveGroupWithOneOperation, &QAction::triggered, this, &SKGOperationPlugin::onRemoveGroupWithOneOperation);
+    registerGlobalAction("clean_remove_group_with_one_operation", m_cleanRemoveGroupWithOneOperation);
 
     // ------------
     m_groupOperation = new QAction(QIcon::fromTheme("view-financial-transfer"), i18nc("Verb", "Group operations"), this);
@@ -352,8 +355,18 @@ void SKGOperationPlugin::refresh()
         if (m_open) {
             m_open->setEnabled(nb > 0);
         }
+        bool onOperation = (nb > 0 && selection.at(0).getRealTable() == "operation");
+        m_cleanAlignDate->setText(onOperation ? i18nc("Verb", "Align date of suboperations of selected operations") : i18nc("Verb", "Align date of suboperations of all operations"));
+        m_cleanAlignDate->setData(onOperation);
+
+        m_cleanAlignComment->setText(onOperation ? i18nc("Verb", "Align comment of suboperations of selected operations") : i18nc("Verb", "Align comment of suboperations of all operations"));
+        m_cleanAlignComment->setData(onOperation);
+
+        m_cleanRemoveGroupWithOneOperation->setText(onOperation ? i18nc("Verb", "Remove groups with only one operation of selected operations") : i18nc("Verb", "Remove groups with only one operation of all operations"));
+        m_cleanRemoveGroupWithOneOperation->setData(onOperation);
+
         if (nb > 0) {
-            bool onOperation = (selection.at(0).getRealTable() == "operation");
+
             if (m_duplicateAction) {
                 m_duplicateAction->setEnabled(onOperation);
             }
@@ -1356,8 +1369,23 @@ void SKGOperationPlugin::onRemoveGroupWithOneOperation()
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
     {
+        SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+        QAction* act = qobject_cast< QAction* >(sender());
+        if (!act || !act->data().toBool()) {
+            // Clear selection to enable the model "All"
+            selection.clear();
+        }
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Remove groups with only one operation"), err);
-        err = m_currentBankDocument->executeSqliteOrder("UPDATE operation SET i_group_id=0 WHERE i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=operation.i_group_id)<2");
+        QString q = "UPDATE operation SET i_group_id=0 WHERE i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=operation.i_group_id)<2";
+        int nb = selection.count();
+        if (nb == 0) {
+            err = m_currentBankDocument->executeSqliteOrder(q);
+        } else {
+            for (int i = 0; !err && i < nb; ++i) {
+                SKGOperationObject op(selection.at(i));
+                err = m_currentBankDocument->executeSqliteOrder(q % " AND id=" % SKGServices::intToString(op.getID()));
+            }
+        }
     }
 
     // status bar
@@ -1376,8 +1404,23 @@ void SKGOperationPlugin::onAlignComment()
     SKGTRACEINFUNCRC(10, err);
 
     {
+        SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+        QAction* act = qobject_cast< QAction* >(sender());
+        if (!act || !act->data().toBool()) {
+            // Clear selection to enable the model "All"
+            selection.clear();
+        }
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Align comment of suboperations"), err);
-        err = m_currentBankDocument->executeSqliteOrder("UPDATE suboperation SET t_comment=(SELECT op.t_comment FROM operation op WHERE suboperation.rd_operation_id=op.id) WHERE suboperation.id IN (SELECT so.id FROM operation op, suboperation so WHERE so.rd_operation_id=op.id AND so.t_comment<>op.t_comment AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1)");
+        QString q = "UPDATE suboperation SET t_comment=(SELECT op.t_comment FROM operation op WHERE suboperation.rd_operation_id=op.id) WHERE suboperation.id IN (SELECT so.id FROM operation op, suboperation so WHERE so.rd_operation_id=op.id AND so.t_comment<>op.t_comment AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1)";
+        int nb = selection.count();
+        if (nb == 0) {
+            err = m_currentBankDocument->executeSqliteOrder(q);
+        } else {
+            for (int i = 0; !err && i < nb; ++i) {
+                SKGOperationObject op(selection.at(i));
+                err = m_currentBankDocument->executeSqliteOrder(q % " AND rd_operation_id=" % SKGServices::intToString(op.getID()));
+            }
+        }
     }
 
     // status bar
@@ -1396,8 +1439,23 @@ void SKGOperationPlugin::onAlignDate()
     SKGTRACEINFUNCRC(10, err);
 
     {
+        SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+        QAction* act = qobject_cast< QAction* >(sender());
+        if (!act || !act->data().toBool()) {
+            // Clear selection to enable the model "All"
+            selection.clear();
+        }
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Align date of suboperations"), err);
-        err = m_currentBankDocument->executeSqliteOrder("UPDATE suboperation SET d_date=(SELECT op.d_date FROM operation op WHERE suboperation.rd_operation_id=op.id) WHERE suboperation.id IN (SELECT so.id FROM operation op, suboperation so WHERE so.rd_operation_id=op.id AND so.d_date<>op.d_date AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1)");
+        QString q = "UPDATE suboperation SET d_date=(SELECT op.d_date FROM operation op WHERE suboperation.rd_operation_id=op.id) WHERE suboperation.id IN (SELECT so.id FROM operation op, suboperation so WHERE so.rd_operation_id=op.id AND so.d_date<>op.d_date AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1)";
+        int nb = selection.count();
+        if (nb == 0) {
+            err = m_currentBankDocument->executeSqliteOrder(q);
+        } else {
+            for (int i = 0; !err && i < nb; ++i) {
+                SKGOperationObject op(selection.at(i));
+                err = m_currentBankDocument->executeSqliteOrder(q % " AND rd_operation_id=" % SKGServices::intToString(op.getID()));
+            }
+        }
     }
 
     // status bar
