@@ -186,6 +186,9 @@ private:
     QAction* m_ungroupOperation;
     QAction* m_mergeOperationAction;
     QAction* m_open;
+    QAction* m_cleanAlignDate;
+    QAction* m_cleanAlignComment;
+    QAction* m_cleanRemoveGroupWithOneOperation;
     KToolBarPopupAction* m_applyTemplateAction;
     QMenu* m_applyTemplateMenu;
 
