@@ -22,9 +22,11 @@
 #include "skgsplittabledelegate.h"
 
 #include <KSqueezedTextLabel>
+#include <KFormat>
 
 #include <QPainter>
 
+#include "skgbasegui_settings.h"
 #include "skgcombobox.h"
 #include "skgcalculatoredit.h"
 #include "skgmainpanel.h"
@@ -117,9 +119,11 @@ void SKGSplitTableDelegate::setModelData(QWidget* editor, QAbstractItemModel* mo
     } else if (index.column() == m_listAttributes.indexOf("d_date")) {
         SKGDateEdit* date = static_cast<SKGDateEdit*>(editor);
         if (date && model) {
-            QString d = SKGServices::dateToSqlString(date->date());
-            model->setData(index, d, Qt::ToolTipRole);
-            model->setData(index, d, Qt::DisplayRole);
+            QString dateDisplay = SKGMainPanel::dateToString(date->date());;
+            QString dateInternal = SKGServices::dateToSqlString(date->date());;
+
+            model->setData(index, dateInternal, Qt::ToolTipRole);
+            model->setData(index, dateDisplay, Qt::DisplayRole);
         }
     } else {
         QItemDelegate::setModelData(editor, model, index);
