@@ -102,6 +102,10 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     QMenu* tableMenu = ui.kTableWithGraph->getTableContextualMenu();
     if (tableMenu) {
         tableMenu->addSeparator();
+        m_openAction = tableMenu->addAction(QIcon::fromTheme("quickopen"), i18nc("Verb", "Open..."));
+        if (m_openAction) {
+            m_openAction->setEnabled(false);
+        }
         QStringList overlayopen;
         overlayopen.push_back("quickopen");
         m_openReportAction = tableMenu->addAction(SKGServices::fromTheme("view-statistics", overlayopen), i18nc("Verb", "Open report..."));
@@ -113,9 +117,11 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     QMenu* graphMenu = ui.kTableWithGraph->getGraphContextualMenu();
     if (graphMenu) {
         graphMenu->addSeparator();
+        graphMenu->addAction(m_openAction);
         graphMenu->addAction(m_openReportAction);
     }
 
+    connect(m_openAction, &QAction::triggered, this, &SKGReportPluginWidget::onOpen);
     connect(m_openReportAction, &QAction::triggered, this, &SKGReportPluginWidget::onOpenReport);
 
     // Init comboboxes
@@ -185,6 +191,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
 SKGReportPluginWidget::~SKGReportPluginWidget()
 {
     SKGTRACEINFUNC(10);
+    m_openAction = NULL;
     m_openReportAction = NULL;
 }
 
@@ -433,7 +440,7 @@ QList< QWidget* > SKGReportPluginWidget::printableWidgets()
     return output;
 }
 
-void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int column, QString& oWc, QString& oTitle)
+void SKGReportPluginWidget::getWhereClauseAndTitleForItem(int row, int column, QString& oWc, QString& oTitle)
 {
     // Build where clause and title
     oTitle.clear();
@@ -555,13 +562,43 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
     oTitle += i18nc("Noun",  "during '%1' for '%2'", during, types.join(" "));
 }
 
+void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(QString& oWc, QString& oTitle)
+{
+    oWc.clear();
+    oTitle.clear();
+
+    QList<QTableWidgetItem*> selection = ui.kTableWithGraph->table()->selectedItems();
+    int nb = selection.count();
+    if (nb) {
+        for (int i = 0; i < nb; ++i) {
+            QString wc2;
+            QString title2;
+            getWhereClauseAndTitleForItem(selection.at(i)->row(), selection.at(i)->column(), wc2, title2);
+            if (!wc2.isEmpty()) {
+                if (!oWc.isEmpty()) {
+                    oWc = '(' % oWc % ") OR (" % wc2 % ')';
+                } else {
+                    oWc = wc2;
+                }
+            }
+            if (!title2.isEmpty()) {
+                if (!oTitle.isEmpty()) {
+                    oTitle = i18n("(%1) or (%2)", oTitle, title2);
+                } else {
+                    oTitle = title2;
+                }
+            }
+        }
+    }
+}
+
 void SKGReportPluginWidget::onDoubleClick(int row, int column)
 {
     _SKGTRACEINFUNC(10);
 
     QString wc;
     QString title;
-    getWhereClauseAndTitleForSelection(row, column, wc, title);
+    getWhereClauseAndTitleForItem(row, column, wc, title);
     SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=view-statistics&operationTable=v_suboperation_consolidated&operationWhereClause=" % SKGServices::encodeForUrl(wc) % "&title=" % SKGServices::encodeForUrl(title));
 }
 
@@ -570,35 +607,22 @@ void SKGReportPluginWidget::onBtnModeClicked(int mode)
     ui.kTableWithGraph->setFilterVisibility(mode == 0);
 }
 
+void SKGReportPluginWidget::onOpen()
+{
+    QString wc;
+    QString title;
+    getWhereClauseAndTitleForSelection(wc, title);
+    SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=view-statistics&operationTable=v_suboperation_consolidated&operationWhereClause=" % SKGServices::encodeForUrl(wc) % "&title=" % SKGServices::encodeForUrl(title));
+}
+
 void SKGReportPluginWidget::onOpenReport()
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
-    QList<QTableWidgetItem*> selection = ui.kTableWithGraph->table()->selectedItems();
-    int nb = selection.count();
-    if (nb) {
-        QString wc;
-        QString title;
-        for (int i = 0; i < nb; ++i) {
-            QString wc2;
-            QString title2;
-            getWhereClauseAndTitleForSelection(selection.at(i)->row(), selection.at(i)->column(), wc2, title2);
-            if (!wc2.isEmpty()) {
-                if (!wc.isEmpty()) {
-                    wc = '(' % wc % ") OR (" % wc2 % ')';
-                } else {
-                    wc = wc2;
-                }
-            }
-            if (!title2.isEmpty()) {
-                if (!title.isEmpty()) {
-                    title = i18n("(%1) or (%2)", title, title2);
-                } else {
-                    title = title2;
-                }
-            }
-        }
-
+    QString wc;
+    QString title;
+    getWhereClauseAndTitleForSelection(wc, title);
+    if (!wc.isEmpty()) {
         // Call report plugin
         QDomDocument doc("SKGML");
         doc.setContent(getState());
@@ -723,6 +747,9 @@ void SKGReportPluginWidget::onSelectionChanged()
     if (m_openReportAction) {
         m_openReportAction->setEnabled(ui.kTableWithGraph->table()->selectedItems().count() > 0);
     }
+    if (m_openAction) {
+        m_openAction->setEnabled(ui.kTableWithGraph->table()->selectedItems().count() > 0);
+    }
 }
 
 void SKGReportPluginWidget::refresh()
