@@ -34,6 +34,7 @@
 #include <QKeyEvent>
 #include <qdir.h>
 #include <qstandardpaths.h>
+#include <QRegExpValidator>
 
 #include "skgmainpanel.h"
 #include "skgobjectmodel.h"
@@ -113,6 +114,9 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     ui.kDeleteSource->setIcon(QIcon::fromTheme("edit-delete"));
     ui.kGetNewHotStuff->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
 
+    QRegExpValidator* newValidator = new QRegExpValidator(QRegExp("^[\\w\\s]+$"), this);
+    ui.kDownloadSource->setValidator(newValidator);
+
     QStringList overlays;
     overlays.push_back("list-add");
     m_upload = new QAction(SKGServices::fromTheme("get-hot-new-stuff", overlays), i18n("Upload"), this);
