@@ -23,10 +23,7 @@
 
 #include <math.h>
 
-#include <QIcon>
 #include <klocalizedstring.h>
-#include <klocalizedstring.h>
-
 #include <KConfigGroup>
 
 #include <qapplication.h>
@@ -34,6 +31,7 @@
 #include <QMimeData>
 #include <QFont>
 #include <QColor>
+#include <QIcon>
 #include <qstandardpaths.h>
 
 #include "skgdocumentbank.h"
@@ -675,8 +673,8 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                         }
                         toolTipString += i18nc("Noun", "Original amount=%1 (%2 = %3 / year)",
                                                SKGServices::toCurrencyString(val2, primaryUnit.Symbol, primaryUnit.NbDecimal),
-                                               (gain >= 0 ? "+" : "-") % SKGServices::toCurrencyString(gain, "%", 2),
-                                               (gainperyear >= 0 ? "+" : "-") % SKGServices::toCurrencyString(gainperyear, "%", 2));
+                                               (gain >= 0 ? "+" : "-") % SKGServices::toPercentageString(gain, 2),
+                                               (gainperyear >= 0 ? "+" : "-") % SKGServices::toPercentageString(gainperyear, 2));
                     } else {
                         if (!toolTipString.isEmpty()) {
                             toolTipString += "\n\n";
@@ -697,8 +695,8 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                         if (sval1 != sval2) {
                             toolTipString += i18nc("Noun", "Amount at creation date=%1 (%2 = %3 / year)",
                                                    sval2,
-                                                   (gain >= 0 ? "+" : "-") % SKGServices::toCurrencyString(gain, "%", 2),
-                                                   (gainperyear >= 0 ? "+" : "-") % SKGServices::toCurrencyString(gainperyear, "%", 2));
+                                                   (gain >= 0 ? "+" : "-") % SKGServices::toPercentageString(gain, 2),
+                                                   (gainperyear >= 0 ? "+" : "-") % SKGServices::toPercentageString(gainperyear, 2));
 
                             toolTipString += '\n';
                         }
