@@ -710,3 +710,18 @@ QString SKGRuleObject::getDescriptionFromXML(SKGDocument* iDocument, const QStri
     return output;
 }
 
+SKGError SKGRuleObject::createPayeeCategoryRule(SKGDocument* iDocument, const QString& iPayee, const QString& iCategory, SKGRuleObject& oRule)
+{
+    SKGError err;
+    oRule = SKGRuleObject(iDocument);
+    // TODO escape values
+    IFOKDO(err, oRule.setActionType(SKGRuleObject::UPDATE))
+    IFOKDO(err, oRule.setSearchDescription(iDocument->getDisplay("t_PAYEE") % ' ' % getDisplayForOperator("#ATT#='#V1S#'", iPayee, "", "")))
+    IFOKDO(err, oRule.setXMLSearchDefinition("<!DOCTYPE SKGML><element> <!--OR--> <element>  <!--AND-->  <element value=\"" % iPayee % "\" attribute=\"t_PAYEE\" operator=\"#ATT#='#V1S#'\"/> </element></element>"))
+    IFOKDO(err, oRule.setActionDescription(iDocument->getDisplay("t_REALCATEGORY") % ' ' % getDisplayForOperator("#ATT#='#V1S#'", iCategory, "", "")))
+    IFOKDO(err, oRule.setXMLActionDefinition("<!DOCTYPE SKGML><element> <!--OR--> <element>  <!--AND-->  <element value=\"" % iCategory % "\" attribute=\"t_REALCATEGORY\" operator=\"#ATT#='#V1S#'\"/> </element></element>"))
+    IFOKDO(err, oRule.save())
+
+    return err;
+}
+
