@@ -1831,7 +1831,7 @@ bool SKGMainPanel::openPage(const QUrl& iUrl, bool iNewPage)
                     doc.appendChild(root);
                 }
                 auto params = QUrlQuery(url).queryItems();
-                foreach(auto p, params) {
+                foreach(const auto & p, params) {
                     QString value = QUrl::fromPercentEncoding(p.second.toLatin1());
                     SKGMainPanelPrivate::setAttribute(root, p.first, value);
                 }
@@ -2284,15 +2284,14 @@ void SKGMainPanel::onQuitAction()
 QString SKGMainPanel::getSaveFileName(const QString& startDir, const QString& filter, QWidget* iParent, const QString& caption, QString* iCodec)
 {
     QString fileName;
+
+    QString lastCodecUsed = QTextCodec::codecForLocale()->name();
+    KEncodingFileDialog::Result result = KEncodingFileDialog::getSaveUrlAndEncoding(lastCodecUsed, QUrl(startDir), filter , iParent, caption);
+    if (result.URLs.count()) {
+        fileName = result.URLs.at(0).toLocalFile();
+    }
     if (iCodec) {
-        QString lastCodecUsed = QTextCodec::codecForLocale()->name();
-        KEncodingFileDialog::Result result = KEncodingFileDialog::getSaveUrlAndEncoding(lastCodecUsed, QUrl(startDir), filter , iParent, caption);
-        if (result.URLs.count()) {
-            fileName = result.URLs.at(0).toString();
-        }
         *iCodec = result.encoding;
-    } else {
-        fileName = QFileDialog::getSaveFileName(iParent, caption, startDir, filter);
     }
     if (fileName.isEmpty()) {
         return "";
@@ -2413,3 +2412,19 @@ void SKGMainPanel::onClearMessages()
     }
 }
 
+QString SKGMainPanel::dateToString(const QDate& iDate)
+{
+    switch (skgbasegui_settings::date_format()) {
+    case 0:
+        return QLocale().toString(iDate, QLocale::ShortFormat);
+    case 1:
+        return QLocale().toString(iDate, QLocale::LongFormat);
+    case 3:
+        return KFormat().formatRelativeDate(iDate, QLocale::LongFormat);
+    case 4:
+        return iDate.toString(Qt::ISODate);
+    case 2:
+    default:
+        return KFormat().formatRelativeDate(iDate, QLocale::ShortFormat);
+    }
+}
