@@ -125,6 +125,13 @@ public:
      */
     static KConfigGroup getMainConfigGroup();
 
+    /**
+     * Convert a QDate into a QString based on application settings.
+     * @param iDate the date
+     * @return the converted QString
+     */
+    static QString dateToString(const QDate& iDate);
+
 public Q_SLOTS:
 
     /**
