@@ -678,19 +678,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
                 case SKGServices::DATE: {
                     QDate dval = SKGServices::stringToTime(val).date();
                     if (iRole == Qt::DisplayRole) {
-                        switch (skgbasegui_settings::date_format()) {
-                        case 0:
-                            return QLocale().toString(dval, QLocale::ShortFormat);
-                        case 1:
-                            return QLocale().toString(dval, QLocale::LongFormat);
-                        case 3:
-                            return KFormat().formatRelativeDate(dval, QLocale::LongFormat);
-                        case 4:
-                            return dval.toString(Qt::ISODate);
-                        case 2:
-                        default:
-                            return KFormat().formatRelativeDate(dval, QLocale::ShortFormat);
-                        }
+                        return SKGMainPanel::dateToString(dval);
                     }
                 }
                 default: {
@@ -790,7 +778,6 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
                 QString fancyDate = QLocale().toString(dval, QLocale::LongFormat);
                 QString shortDate = QLocale().toString(dval, QLocale::ShortFormat);
 
-
                 if (shortDate != fancyDate) {
                     toolTipString = shortDate;
                 }
