@@ -478,7 +478,7 @@ void SKGTreeView::setupHeaderMenu()
             if (m_actGroupByNone) {
                 m_actGroupByNone->setIcon(QIcon::fromTheme("dialog-cancel"));
                 m_actGroupByNone->setCheckable(true);
-                m_actGroupByNone->setChecked(m_groupby == QString());
+                m_actGroupByNone->setChecked(m_groupby.isEmpty());
                 m_actGroupByNone->setData("");
                 groupby->addAction(m_actGroupByNone);
             }
