@@ -39,6 +39,7 @@
 #include <qfile.h>
 #include <qtemporaryfile.h>
 #include <QtCrypto>
+#include <qmath.h>
 
 #include <QDomDocument>
 #include <QScriptEngine>
@@ -65,23 +66,42 @@ QString SKGServices::searchCriteriasToWhereClause(const QList< SKGServices::SKGS
 
             QString word = criteria.words[w].toLower();
             QString att;
-            QChar op = ':';
+            QString op(':');
 
             // Check if the word follows the format attribut:value
-            int pos = word.indexOf(':');
-            int pos2 = word.indexOf('<');
-            int pos3 = word.indexOf('>');
+            int pos = word.indexOf(":");
+            int pos2 = word.indexOf("<=");
+            int pos3 = word.indexOf(">=");
+            int pos4 = word.indexOf("=");
+            int pos5 = word.indexOf("<");
+            int pos6 = word.indexOf(">");
+            int pos7 = word.indexOf("#");
+            int opLength = 1;
             if (pos2 != -1 && (pos2 < pos || pos == -1)) {
                 pos = pos2;
+                opLength = 2;
             }
             if (pos3 != -1 && (pos3 < pos || pos == -1)) {
                 pos = pos3;
+                opLength = 2;
+            }
+            if (pos4 != -1 && (pos4 < pos || pos == -1)) {
+                pos = pos4;
+            }
+            if (pos5 != -1 && (pos5 < pos || pos == -1)) {
+                pos = pos5;
+            }
+            if (pos6 != -1 && (pos6 < pos || pos == -1)) {
+                pos = pos6;
+            }
+            if (pos7 != -1 && (pos7 < pos || pos == -1)) {
+                pos = pos7;
             }
 
             if (pos != -1) {
-                att = word.left(pos).toLower();
-                op = word[pos];
-                word = word.right(word.count() - pos - 1);
+                att = word.left(pos);
+                op = word.mid(pos, opLength);
+                word = word.right(word.count() - pos - op.count());
             }
 
             for (int j = 0; j < nbAttributes; ++j) {
@@ -95,27 +115,30 @@ QString SKGServices::searchCriteriasToWhereClause(const QList< SKGServices::SKGS
                     if (attDatabase.startsWith(QLatin1String("p_"))) {
                         // Case property
                         QString propName = attDatabase.right(attDatabase.length() - 2);
-                        if (op == '<' || op == '>') {
+                        if (op == ":") {
+                            subWhereClause2 = subWhereClause2 % "i_PROPPNAME='" % SKGServices::stringToSqlString(propName) % "' AND (lower(i_PROPVALUE) LIKE '%" % word % "%')";
+                        } else if (op == "#") {
+                            subWhereClause2 = subWhereClause2 % "i_PROPPNAME='" % SKGServices::stringToSqlString(propName) % "' AND REGEXP('" % word % "',i_PROPVALUE)";
+                        } else {
                             attDatabase = "i_PROPPNAME='" % SKGServices::stringToSqlString(propName) % "' AND i_PROPVALUE";
                             if (attDatabase.startsWith(QLatin1String("f_")) || attDatabase.startsWith(QLatin1String("i_"))) {
                                 subWhereClause2 = subWhereClause2 % attDatabase % op % word;
                             } else {
-                                subWhereClause2 = subWhereClause2 % attDatabase % op % "'" % word % "'";
+                                subWhereClause2 = subWhereClause2 % "lower(" % attDatabase % ")" % op % "'" % word % "'";
                             }
-                        } else {
-                            subWhereClause2 = subWhereClause2 % "i_PROPPNAME='" % SKGServices::stringToSqlString(propName) % "' AND (lower(i_PROPVALUE) LIKE '%" % word % "%')";
                         }
                     } else {
                         // Case normal attribute
-                        if (op == '<' || op == '>') {
-
+                        if (op == ":") {
+                            subWhereClause2 = subWhereClause2 % "lower(" % attDatabase % ") LIKE '%" % word % "%'";
+                        } else if (op == "#") {
+                            subWhereClause2 = subWhereClause2 % "REGEXP('" % word % "'," % attDatabase % ")";
+                        } else {
                             if (attDatabase.startsWith(QLatin1String("f_")) || attDatabase.startsWith(QLatin1String("i_"))) {
                                 subWhereClause2 = subWhereClause2 % attDatabase % op % word;
                             } else {
-                                subWhereClause2 = subWhereClause2 % attDatabase % op % "'" % word % "'";
+                                subWhereClause2 = subWhereClause2 % "lower(" % attDatabase % ")" % op % "'" % word % "'";
                             }
-                        } else {
-                            subWhereClause2 = subWhereClause2 % "lower(" % attDatabase % ") LIKE '%" % word % "%'";
                         }
                     }
                 }
@@ -373,9 +396,9 @@ QString SKGServices::timeToString(const QDateTime& iDateTime)
     return d.toString("yyyy-MM-dd HH:mm:ss");
 }
 
-QString SKGServices::dateToSqlString(const QDate& iDateTime)
+QString SKGServices::dateToSqlString(const QDate& iDate)
 {
-    return dateToSqlString(QDateTime(iDateTime));
+    return dateToSqlString(QDateTime(iDate));
 }
 
 QString SKGServices::dateToSqlString(const QDateTime& iDateTime)
@@ -415,6 +438,74 @@ QDateTime SKGServices::stringToTime(const QString& iDateString)
     return output;
 }
 
+QDate SKGServices::partialStringToDate(const QString& iDateString, bool iFixupBackward)
+{
+    QDate result;
+    QStringList items = iDateString.split('/');
+    int size = items.count();
+    bool ok = false;
+
+    if (size == 1) {
+        int dayCount = items.at(0).toInt(&ok);
+
+        result = QDate::currentDate();
+        result = result.addDays(dayCount - result.day());
+
+        if (iFixupBackward) {
+            if (result > QDate::currentDate()) {
+                result = result.addMonths(-1);
+            }
+        } else {
+            if (result < QDate::currentDate()) {
+                result = result.addMonths(1);
+            }
+        }
+    } else if (size == 2) {
+        int dayCount = items.at(0).toInt(&ok);
+        int monthCount = items.at(1).toInt(&ok);
+
+        result = QDate::currentDate();
+        result = result.addDays(dayCount - result.day());
+        result = result.addMonths(monthCount - result.month());
+
+        if (iFixupBackward) {
+            if (result > QDate::currentDate()) {
+                result = result.addYears(-1);
+            }
+        } else {
+            if (result < QDate::currentDate()) {
+                result = result.addYears(1);
+            }
+        }
+    } else if (size == 3) {
+        int dayCount = items.at(0).toInt(&ok);
+        int monthCount = items.at(1).toInt(&ok);
+        int yearCount = items.at(2).toInt(&ok);
+        int lengthYear = items.at(2).count();
+
+        result = QDate::currentDate();
+        result = result.addDays(dayCount - result.day());
+        result = result.addMonths(monthCount - result.month());
+
+        if (lengthYear < 4) {
+            int y = int(result.year() / qPow(10, lengthYear)) * qPow(10, lengthYear) + yearCount;
+            if (y > result.year() && iFixupBackward) {
+                y = y - qPow(10, lengthYear);
+            } else if (y < result.year() && !iFixupBackward) {
+                y = y + qPow(10, lengthYear);
+            }
+            result = result.addYears(y - result.year());
+        } else {
+            result = result.addYears(yearCount - result.year());
+        }
+    }
+
+    if (!ok) {
+        result = QDate();
+    }
+    return result;
+}
+
 QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSeparator, bool iCoteDefineBlock, QChar* oRealSeparator)
 {
     QStringList items;
@@ -676,8 +767,16 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
     return "";
 }
 
+QString SKGServices::toPercentageString(double iAmount, int iNbDecimal)
+{
+    return toCurrencyString(iAmount, QString(), iNbDecimal) % " %";
+}
+
 QString SKGServices::toCurrencyString(double iAmount, const QString& iSymbol, int iNbDecimal)
 {
+    if (iSymbol == "%") {
+        return toPercentageString(iAmount, iNbDecimal);
+    }
     //return QLocale().toCurrencyString(iAmount, iSymbol.isEmpty() ? " " : iSymbol).trimmed();
     return KLocale::global()->formatMoney(iAmount, iSymbol.isEmpty() ? " " : iSymbol, iNbDecimal).trimmed();
 }
