@@ -287,10 +287,18 @@ public:
     /**
      * Convert a QString to QDateTime.
      * @param iDateString the time. The format must be "%Y-%m-%d %H-%M-%S" or "%Y-%m-%d"
-     * @return the converted time_t
+     * @return the converted QDateTime
      */
     static QDateTime stringToTime(const QString& iDateString);
 
+    /**
+     * Convert a QString to QDate.
+     * @param iDateString the date string. Could be a partial date like 1/12.
+     * @param iFixupBackward the date string is fixed in backward mode.
+     * @return the converted QDate
+     */
+    static QDate partialStringToDate(const QString& iDateString, bool iFixupBackward = true);
+
     /**
      * Convert a QDateTime into a QString ready for sql order.
      * The output format is "%Y-%m-%d"
@@ -300,12 +308,12 @@ public:
     static QString dateToSqlString(const QDateTime& iDateTime);
 
     /**
-     * Convert a QDateTime into a QString ready for sql order.
+     * Convert a QDate into a QString ready for sql order.
      * The output format is "%Y-%m-%d"
-     * @param iDateTime the time
+     * @param iDate the date
      * @return the converted QString
      */
-    static QString dateToSqlString(const QDate& iDateTime);
+    static QString dateToSqlString(const QDate& iDate);
 
     /**
      * Format a date.
@@ -350,12 +358,20 @@ public:
      */
     static QString getDateFormat(const QStringList& iDates);
 
+    /**
+     * Get the string representing the percentage
+     * @param iAmount the amount
+     * @param iNbDecimal the number of decimals
+     * @return the string.
+     */
+    static QString toPercentageString(double iAmount, int iNbDecimal = 2);
+
     /**
      * Get the string representing the amount
      * @param iAmount the amount
      * @param iSymbol the symbol
      * @param iNbDecimal the number of decimals
-     * @return the supported format of all of these dates.
+     * @return the string.
      */
     static QString toCurrencyString(double iAmount, const QString& iSymbol = QString(), int iNbDecimal = 2);
 
